class Dater < ActiveRecord::Base
  has_and_belongs_to_many :reviews
  has_and_belongs_to_many :restaurants

  attr_accessible :name, :email, :password, :password_confirmation, :owner
  has_secure_password

  before_save { |moviegoer| moviegoer.email = moviegoer.email.downcase }
  before_save :create_remember_token
  validates :name, presence: true, length: {maximum: 50}
  VALID_EMAIL_REGEX = /\A[\w+\-.]+@[a-z\d\-.]+\.[a-z]+\z/i
  validates :email, presence: true,format: {with: VALID_EMAIL_REGEX},uniqueness: {case_sensitive: false}	
  validates :password, presence: true, length: {minimum: 6}
  validates :password_confirmation, presence: true

  private
    def create_remember_token
      if self.remember_token == nil
       self.remember_token = SecureRandom.urlsafe_base64
      end
    end
end
